@@ -5,7 +5,7 @@ package CPAN::Meta::X;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-08-27'; # DATE
 our $DIST = 'CPAN-Meta-X'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 1;
 # ABSTRACT: Custom (x_*) keys in CPAN distribution metadata being used in the wild
@@ -22,7 +22,7 @@ CPAN::Meta::X - Custom (x_*) keys in CPAN distribution metadata being used in th
 
 =head1 VERSION
 
-This document describes version 0.005 of CPAN::Meta::X (from Perl distribution CPAN-Meta-X), released on 2021-08-27.
+This document describes version 0.006 of CPAN::Meta::X (from Perl distribution CPAN-Meta-X), released on 2021-08-27.
 
 =head1 DESCRIPTION
 
@@ -150,6 +150,25 @@ References:
 
 See L</"x_benchmarks phase">.
 
+=head2 x_features_from relationship
+
+Express that one of the modules in the current distribution is declaring
+features that are defined defined in an associated C<Module::Features::*>
+module. Used with (phase=develop).
+
+Examples: L<Text::ANSITable>, L<Text::Table::More>, and L<Text::Table::Sprintf>
+declares features defined by L<Module::Features::TextTable> so they add a
+dependency (phase=develop, rel=x_features_from) to
+L<Module::Features::TextTable>.
+
+References:
+
+=over
+
+=item * L<Module::Features> specification
+
+=back
+
 =head2 x_mentions relationship
 
 See L</"x_mentions phase">.
